const express = require('express');
const morgan = require('morgan');
const rfs = require('rotating-file-stream');
const nunjucks = require('nunjucks');
const moment = require('moment');
const session = require('express-session');

const config = require('komodo-sdk/config');
const logger = require('komodo-sdk/logger');

const routerConfig = require('./router/config');
const routerAuth = require('./router/auth');

const app = express();

nunjucks.configure('./webadmin-views', {
    autoescape: true,
    express: app,
    noCache: true,
});

app.use(express.static('./webadmin-statics'));
app.use(session({
    secret: 'b4ba8b94-1bbe-11ea-9815-1c872cb0e3c0',
    resave: false,
    saveUninitialized: true,
}));

const accessLogStream = rfs.createStream(
    (time, index) => {
        const ts = time ? `.${moment(time).format('YYYY-MM-DD')}` : '';
        const idx = index ? `.${index}` : '';
        return `webadmin.access_log${ts}${idx}`;
    },
    {
        interval: '1d',
        path: './logs',
    },
);

app.use(morgan('combined', { stream: accessLogStream }));

app.use((req, res, next) => { // check if user is logged in
    if (!req.session.user && req.path !== '/auth/login') {
        res.redirect('/auth/login');
        return;
    }
    res.locals.loggedInUser = req.session.user;
    next();
});


app.use((req, res, next) => {
    res.locals.config = config;
    next();
});

app.get('/', (req, res) => {
    res.redirect('/config/modem');
});

app.use('/auth', routerAuth);
app.use('/config', routerConfig);

const listenPort = (config.webadmin && config.webadmin.port) || 21923;
app.listen(listenPort, () => {
    logger.info(`WEBADMIN listen on port ${listenPort}`);
}).on('error', (err) => {
    logger.warn(`WEBADMIN can not start / listen on port ${listenPort}`, { err: err.message });
    process.exit();
});
