const express = require('express');
const axios = require('axios');
const querystring = require('querystring');
const config = require('komodo-sdk/config');
const coreUrl = require('komodo-sdk/core-url');
const logger = require('komodo-sdk/logger');

const router = express.Router();
module.exports = router;

function login(req, res) {
    res.render('auth.login.html', {
        baseUrl: req.baseUrl,
    });
}

async function loginProcess(req, res) {
    const params = {
        terminal_name: req.body.terminal_name || '',
        web_password: req.body.web_password || '',
        request_by: config.name,
    };

    try {
        const loginUrl = `${coreUrl}/services/terminalAuthentication?${querystring.stringify(params)}`;
        logger.verbose(`lib/webadmin/router/auth.js:login(): request login to: ${loginUrl}`);
        const response = await axios.get(loginUrl);
        logger.verbose(`lib/webadmin/router/auth.js:login(): status: ${response.status}, body: ${JSON.stringify(response.data)}`);
        if (response.data.error === false && response.data.terminal.store_is_super) {
            req.session.user = response.data;
            res.redirect('/');
            return;
        }
    } catch (err) {
        logger.error(`lib/webadmin/router/auth.js:login(): ${err.message}`);
    }
    res.redirect(`${req.baseUrl}/login?message=Terminal / Password tidak sesuai`);
}

function logout(req, res) {
    req.session.destroy();
    res.redirect(`${req.baseUrl}/login`);
}

router.get('/login', login);
router.post('/login', express.urlencoded({ extended: true }), loginProcess);
router.get('/logout', express.urlencoded({ extended: true }), logout);
